package com.jiuqi.util;

import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Iterator;

public class Html {
   private static final String[] SYS_COLOR_NAMES = new String[]{"scrollbar", "background", "activecaption", "inactivecaption", "menu", "window", "windowframe", "menutext", "windowtext", "captiontext", "inactiveborder", "inactivecaption", "appworkspace", "highlight", "highlighttext", "buttonface", "buttonshadow", "graytext", "buttontext", "inactivecaption", "buttonhighlight", "threeddarkshadow", "threedhighlight", "infotext", "infobackground"};
   private static final int SYS_COLOR_MASK = -16777216;

   private Html() {
   }

   public static String getHtmlColor(int colorValue) {
      String returnStr = "";
      if (colorValue < 0) {
         returnStr = getSystemColor(colorValue);
      } else {
         returnStr = "#" + repairLength(Integer.toHexString(BGR2RGB(colorValue)));
      }

      return returnStr;
   }

   public static int BGR2RGB(int color) {
      if (color < 0) {
         return color;
      } else {
         int red = (color & 255) << 16;
         int blue = (color & 16711680) >> 16;
         int green = color & '\uff00';
         return red | blue | green;
      }
   }

   private static String repairLength(String colorStr) {
      if (colorStr == null) {
         return "000000";
      } else if (colorStr.length() == 6) {
         return colorStr;
      } else {
         StringBuffer buffer = new StringBuffer(colorStr);

         while(buffer.length() < 6) {
            buffer.insert(0, '0');
         }

         return buffer.toString();
      }
   }

   public static String getSystemColor(int intColor) {
      if ((intColor & -16777216) != -16777216) {
         return "";
      } else {
         int colorValue = intColor & 16777215;
         return colorValue < SYS_COLOR_NAMES.length ? SYS_COLOR_NAMES[colorValue] : "";
      }
   }

   /** @deprecated */
   public static String strToHtml(String instring) {
      int lIndex = 0;
      if (instring == null) {
         return "";
      } else {
         StringBuffer lStrbuff = new StringBuffer(instring);

         while(lIndex < lStrbuff.length()) {
            lStrbuff.charAt(lIndex);
            char lChar;
            if ((lChar = lStrbuff.charAt(lIndex)) == '"') {
               lStrbuff.replace(lIndex, lIndex + 1, "&#34;");
               lIndex += 5;
            } else if (lChar == '&') {
               lStrbuff.replace(lIndex, lIndex + 1, "&amp;");
               lIndex += 5;
            } else if (lChar == '<') {
               lStrbuff.replace(lIndex, lIndex + 1, "&lt;");
               lIndex += 4;
            } else if (lChar == '>') {
               lStrbuff.replace(lIndex, lIndex + 1, "&gt;");
               lIndex += 4;
            } else if (lChar == ' ') {
               lStrbuff.replace(lIndex, lIndex + 1, "&nbsp;");
               lIndex += 6;
            } else {
               ++lIndex;
            }
         }

         return lStrbuff.toString();
      }
   }

   public static String encodeText(String inString) {
      if (inString == null) {
         return "";
      } else {
         int lIndex = 0;
         char endChar = 0;
         StringBuffer outString = new StringBuffer(inString);

         while(true) {
            while(lIndex < outString.length()) {
               char lChar = outString.charAt(lIndex);
               if (lIndex + 1 < outString.length()) {
                  endChar = outString.charAt(lIndex + 1);
               }

               if (lChar == '&') {
                  outString.replace(lIndex, lIndex + 1, "&amp;");
                  lIndex += 5;
               } else if (lChar == '<') {
                  outString.replace(lIndex, lIndex + 1, "&lt;");
                  lIndex += 4;
               } else if (lChar == '>') {
                  outString.replace(lIndex, lIndex + 1, "&gt;");
                  lIndex += 4;
               } else if ((lChar = outString.charAt(lIndex)) == '"') {
                  outString.replace(lIndex, lIndex + 1, "&#34;");
                  lIndex += 5;
               } else if (lChar == '\r' && endChar == '\n') {
                  outString.replace(lIndex, lIndex + 2, "<br>");
                  lIndex += 4;
               } else if (lChar == ' ') {
                  outString.replace(lIndex, lIndex + 1, "&nbsp;");
                  lIndex += 6;
               } else {
                  ++lIndex;
               }
            }

            return outString.toString();
         }
      }
   }

   /** @deprecated */
   public static String Double2Str(double value) {
      DecimalFormat df = new DecimalFormat("#.#");
      return df.format(value);
   }

   /** @deprecated */
   public static String fmtDouble(double value) {
      DecimalFormat df = new DecimalFormat("0.0000");
      return df.format(value);
   }

   public static String encodeHashMap(HashMap hashMap) {
      if (hashMap != null && !hashMap.isEmpty()) {
         StringBuffer result = new StringBuffer();

         for(Iterator keys = hashMap.keySet().iterator(); keys.hasNext(); result.append(';')) {
            Object key = keys.next();
            result.append(key);
            result.append(':');
            Object value = hashMap.get(key);
            if (value != null) {
               result.append(value);
            }
         }

         if (result.length() > 0) {
            result.deleteCharAt(result.length() - 1);
         }

         return result.toString();
      } else {
         return null;
      }
   }

   public static HashMap decodeHashMap(String s) {
      if (StringUtils.isEmpty(s)) {
         return null;
      } else {
         HashMap result = new HashMap();
         String[] maps = s.split(";");
         if (maps == null) {
            return result;
         } else {
            for(int i = 0; i < maps.length; ++i) {
               if (!StringUtils.isEmpty(maps[i])) {
                  String[] entries = maps[i].split(":");
                  if (entries != null) {
                     if (entries.length == 1) {
                        result.put(entries[0], (Object)null);
                     } else if (entries.length == 2) {
                        result.put(entries[0], entries[1]);
                     }
                  }
               }
            }

            return result;
         }
      }
   }
}
